package org.jabricks.templates;

import java.awt.Color;
import java.awt.Font;
import java.awt.BorderLayout;
import java.awt.event.ActionListener;

import java.util.Locale;
import java.util.Properties;
import java.util.ResourceBundle;

import javax.swing.JLabel;
import javax.swing.JPanel;

import org.jabricks.jframe.JBFrame;
import org.osgi.framework.BundleContext;
import org.jabricks.resources.IResources;
import org.jabricks.resources.ResourcesImpl;

import org.jabricks.widgets.constants.IWidgetsConstants;

public class JFrameTempl extends JBFrame implements IWidgetsConstants
{
	//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	public JFrameTempl (final BundleContext context)
	{
		super(context);
	}
    //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	@Override
	public void createJFrame(ActionListener menuListener, ActionListener toolbarListener)
	{
		super.createJFrame(menuListener, toolbarListener);

		IResources resources = new ResourcesImpl();
		Locale locale = resources.getLocale();
		
		boolean is_first = context.getBundle().getVersion().toString().equalsIgnoreCase("1.0.1");
		if (is_first)
			createGUI();
		
		changeLocale(locale);
        jframe.repaint();

        // Открытие окна
        jframe.setVisible(true);
	}
    //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    /**
     * Процедура смены языка локализации
     */
	@Override
    public void changeLocale(Locale locale)
    {
        /*
         * Внутренние ресурсы : локализованный заголовок фрейма приложения
         */
    	if (locale != null) {
    		ResourceBundle resources_incl = ResourceBundle.getBundle (RESOURCES_props, locale);
            jframe.setTitle(resources_incl.getString(RESOURCE_title));
    	}
        /*
         * Внешние ресурсы : локализованные заголовки пунктов меню и подсказки кнопок панели инструментов
         */
    	IResources resources = new ResourcesImpl();
    	if (resources != null) {
    		Properties props = resources.getBundleResources(context.getBundle().getSymbolicName());
    		// Определение языка локализации меню
    		if (menuService != null)
    			menuService.changeLocale(props);
    		// Определение локализованных подсказок
    		if (tbService != null)
    			tbService.changeLocale(props);
    	}
    }
    //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	private void createGUI()
	{
		JPanel pnlTop    = new JPanel();
		JPanel pnlCenter = new JPanel();
		JPanel pnlBottom = new JPanel();
		
		pnlTop   .setBackground(new Color(216, 216, 216));
		pnlCenter.setBackground(new Color(240, 240, 240));
		pnlBottom.setBackground(new Color(216, 216, 216));
		
		jframe.add(pnlTop   , BorderLayout.NORTH );
		jframe.add(pnlCenter, BorderLayout.CENTER);
		jframe.add(pnlBottom, BorderLayout.SOUTH );
		
		JLabel lblTop    = new JLabel(" ");
		JLabel lblBottom = new JLabel(" ");

		Font font = new Font("Courier New", Font.PLAIN, 48);
		lblTop   .setFont(font);
		lblBottom.setFont(font);
		
		pnlTop   .add(lblTop   );
		pnlBottom.add(lblBottom);
	}
    //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
}
